Graph Learners
===========================

This module provides graph learning algorithms for discovering concept relationships from data.

.. currentmodule:: torch_concepts.nn

Summary
-------

**Graph Learning Classes**

.. autosummary::
   :toctree: generated
   :nosignatures:

   WANDAGraphLearner


Class Documentation
-------------------

.. autoclass:: WANDAGraphLearner
   :members:
   :undoc-members:
   :show-inheritance:
